@@ -1,8 +1,5 @@
 from allauth.socialaccount import app_settings
-from allauth.socialaccount.providers.base import (
-    ProviderAccount,
-    ProviderException,
-)
+from allauth.socialaccount.providers.base import ProviderAccount, ProviderException
 from allauth.socialaccount.providers.globus.views import GlobusOAuth2Adapter
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
