@@ -1,14 +1,10 @@
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
-from allauth.socialaccount.providers.sharefile.views import (
-    ShareFileOAuth2Adapter,
-)
+from allauth.socialaccount.providers.sharefile.views import ShareFileOAuth2Adapter
 
 
 class ShareFileAccount(ProviderAccount):
-    def to_str(self):
-        dflt = super(ShareFileAccount, self).to_str()
-        return self.account.extra_data.get("name", dflt)
+    pass
 
 
 class ShareFileProvider(OAuth2Provider):
